@@ -566,6 +566,8 @@ gtk_file_system_gnome_vfs_get_folder (GtkFileSystem     *file_system,
 				      GError           **error)
 {
   char *uri;
+  GnomeVFSURI *vfs_uri;
+  gboolean exists;
   GtkFilePath *parent_path;
   GtkFileSystemGnomeVFS *system_vfs = GTK_FILE_SYSTEM_GNOME_VFS (file_system);
   GtkFileFolderGnomeVFS *folder_vfs;
@@ -587,6 +589,26 @@ gtk_file_system_gnome_vfs_get_folder (GtkFileSystem     *file_system,
       return NULL;
     }
 
+  vfs_uri = gnome_vfs_uri_new (uri);
+  if (!vfs_uri)
+    {
+      set_vfs_error (GNOME_VFS_ERROR_INVALID_URI, uri, error);
+      gtk_file_path_free (parent_path);
+      g_free (uri);
+      return NULL;
+    }
+
+  exists = gnome_vfs_uri_exists (vfs_uri);
+  gnome_vfs_uri_unref (vfs_uri);
+
+  if (!exists)
+    {
+      set_vfs_error (GNOME_VFS_ERROR_NOT_FOUND, uri, error);
+      gtk_file_path_free (parent_path);
+      g_free (uri);
+      return NULL;
+    }
+
   folder_vfs = g_object_new (GTK_TYPE_FILE_FOLDER_GNOME_VFS, NULL);
 
   gnome_authentication_manager_push_sync ();
@@ -940,7 +962,7 @@ gtk_file_system_gnome_vfs_volume_render_icon (GtkFileSystem        *file_system,
     {
       uri = gnome_vfs_volume_get_activation_uri (GNOME_VFS_VOLUME (volume));
       if (strcmp (uri, "file:///") == 0)
-	icon_name = g_strdup ("gnome-fs-harddisk");
+	icon_name = g_strdup ("gnome-dev-harddisk");
       else if (strcmp (uri, system_vfs->desktop_uri) == 0)
 	icon_name = g_strdup ("gnome-fs-desktop");
       else if (strcmp (uri, system_vfs->home_uri) == 0)
