@@ -40,10 +40,24 @@
     (void) gnome_icon_list_mode_get_type ();
 
 
+/* enumerations from "gnome-icon-lookup.h" */
+    (void) gnome_icon_lookup_flags_get_type ();
+
+    (void) gnome_icon_lookup_result_flags_get_type ();
+
+
 /* enumerations from "gnome-mdi.h" */
     (void) gnome_mdi_mode_get_type ();
 
 
+/* enumerations from "gnome-password-dialog.h" */
+    (void) gnome_password_dialog_remember_get_type ();
+
+
+/* enumerations from "gnome-thumbnail.h" */
+    (void) gnome_thumbnail_size_get_type ();
+
+
 /* enumerations from "gnome-types.h" */
     (void) gnome_preferences_type_get_type ();
 
